pub enum CcdConditioningStrategy {
AllSelected,
AutoTargetSparse,
AutoSharedParents,
AutoGroupOmp,
}Expand description
Strategy for choosing the CCD conditioning set.
Variants
AllSelected
Use every selected conditioning channel except the current target/source pair.
AutoTargetSparse
Choose confounds from channels that best explain the target alone.
Choose confounds from channels that look like shared parents of target and source.
AutoGroupOmp
Choose confounds with a block-OMP style greedy selector on the conditioned baseline fit.